class Channel():
    """ setup legs and feet to correspond to the correct channel """
    LEFT_LEG_FRONT = 0    # channel 0
    LEFT_LEG_BACK = 1     # channel 2
    RIGHT_LEG_FRONT = 2   # channel 6
    RIGHT_LEG_BACK = 3    # channel 4

    LEFT_FOOT_FRONT = 0   # channel 1
    LEFT_FOOT_BACK = 1    # channel 3
    RIGHT_FOOT_FRONT = 2  # channel 7
    RIGHT_FOOT_BACK = 3   # channel 5